@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BOMWindow, Awb0ProductContextInfo, Awb0SavedBookmark, BOMLine
+from tcsoa.gen.BusinessObjects import BOMLine, BOMWindow, Awb0ProductContextInfo, Awb0SavedBookmark
 from typing import Dict, List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
