@@ -1,7 +1,7 @@
 from tcsoa.gen.CalendarManagement._2007_06.services import CalendarManagementService as imp0
 from tcsoa.gen.CalendarManagement._2008_06.services import CalendarManagementService as imp1
 from tcsoa.gen.CalendarManagement._2007_01.services import CalendarManagementService as imp2
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class CalendarManagementService(TcService):
