@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ClassificationService(TcService):
