@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BusinessObject, Cfg0ConfiguratorPerspective, VariantRule, WorkspaceObject
+from tcsoa.gen.BusinessObjects import BusinessObject, WorkspaceObject, VariantRule, Cfg0ConfiguratorPerspective
 from typing import Dict, List
-from tcsoa.gen.Internal.ProductConfiguratorAw._2017_12.ConfiguratorManagement import OptionFamily, OptionValueSelection
+from tcsoa.gen.Internal.ProductConfiguratorAw._2017_12.ConfiguratorManagement import OptionValueSelection, OptionFamily
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
