@@ -4,7 +4,7 @@ from tcsoa.gen.Ai._2006_03.Ai import ApplicationRef
 from tcsoa.gen.Internal.Ai._2008_06.Ai import GenerateMonolithicJtOptions, EndGenerateMonolithicJtResponse, BeginGenerateMonolithicJtResponse
 from tcsoa.gen.BusinessObjects import BusinessObject
 from tcsoa.gen.Ai._2007_12.Ai import Configuration2
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class AiService(TcService):
