@@ -2,7 +2,7 @@ from tcsoa.gen.Internal_Classification._2020_04.services import ClassificationSe
 from tcsoa.gen.Internal_Classification._2017_05.services import ClassificationService as imp1
 from tcsoa.gen.Internal_Classification._2009_10.services import ClassificationService as imp2
 from tcsoa.gen.Internal_Classification._2018_11.services import ClassificationService as imp3
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ClassificationService(TcService):
