@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_Mmv._2012_09.services import SpatialStructureManagementService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class SpatialStructureManagementService(TcService):
