@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_RevRuleMgmt._2019_12.services import RevisionRuleAdministrationService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class RevisionRuleAdministrationService(TcService):
