@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.Security._2017_12.AwLicensing import LicensesWithTypesResponse, LicenseInput
-from tcsoa.utils import TcService
+from tcsoa.gen.Internal.Security._2017_12.AwLicensing import LicenseInput, LicensesWithTypesResponse
+from tcsoa.base import TcService
 
 
 class AwLicensingService(TcService):
