@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_Security._2017_12.services import AwLicensingService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class AwLicensingService(TcService):
