@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from tcsoa.gen.BusinessObjects import BusinessObject, WorkspaceObject
 from typing import Dict, List
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
