@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.Translation._2007_06.TranslationManagement import CreateTranslationRequestResponse, CreateTranslationRequestArgs
+from tcsoa.gen.Translation._2007_06.TranslationManagement import CreateTranslationRequestArgs, CreateTranslationRequestResponse
 from typing import List
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class TranslationManagementService(TcService):
