@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-from tcsoa.gen.Vendormanagement._2007_06.VendorManagement import CreateVendorsResponse, VendorProperties, VendorPartProperties, BidPackageProps, CreateBidPacksResponse, CreateVendorPartsResponse, LineItemProps
+from tcsoa.gen.Vendormanagement._2007_06.VendorManagement import CreateVendorsResponse, CreateVendorPartsResponse, LineItemProps, VendorProperties, BidPackageProps, VendorPartProperties, CreateBidPacksResponse
 from tcsoa.gen.BusinessObjects import BusinessObject
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class VendorManagementService(TcService):
