@@ -4,7 +4,7 @@ from tcsoa.gen.Visualization._2011_02.services import StructureManagementService
 from tcsoa.gen.Visualization._2013_05.services import StructureManagementService as imp3
 from tcsoa.gen.Visualization._2013_12.services import StructureManagementService as imp4
 from tcsoa.gen.Visualization._2016_03.services import DataManagementService as imp5
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DataManagementService(TcService):
