@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from tcsoa.gen.BusinessObjects import BusinessObject
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 from typing import Dict
 
